Standard features for web interface development
===============================================

This chapter describes generic web features built as CubicWeb application objects.

They are used for CubicWeb default automatic interface, but you're free to use
them or not for you're own application.

.. toctree::
   :maxdepth: 1

   basetemplates
   primary
   baseviews
   startup
   boxes
   table
   xmlrss
   autoform
   editforms
   editcontroller
   urlpublish
   breadcrumbs
   facets
   wdoc
   embedding
   idownloadable